<?php

/**
 * @file
 *
 */

namespace Drupal\adobe_dtm\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class AdobeDynamicTagManagementSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'adobe_dtm_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['adobe_dtm.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('adobe_dtm.settings');

    $form['property_embed_code'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Property embed code'),
    ];

    $form['property_embed_code']['property_embed_code_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ID'),
      '#description' => $this->t(''),
      '#default_value' => $config->get('property_embed_code_id'),
      '#size' => 40,
      '#maxlength' => 150,
      '#required' => TRUE,
    ];

    $form['property_embed_code']['property_embed_code_hash'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Hash'),
      '#description' => $this->t(''),
      '#default_value' => $config->get('property_embed_code_hash'),
      '#size' => 40,
      '#maxlength' => 150,
      '#required' => TRUE,
    ];

    $form['environment'] = [
      '#type' => 'select',
      '#title' => t('Environment'),
      '#options' => array(
        'production' => t('Production'),
        'staging' => t('Staging'),
      ),
      '#default_value' => $config->get('environment'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $property_embed_code_id = trim($form_state->getValue('property_embed_code_id'));
    $property_embed_code_hash = trim($form_state->getValue('property_embed_code_hash'));
    $form_state->setValue('property_embed_code_id', $property_embed_code_id);
    $form_state->setValue('property_embed_code_hash', $property_embed_code_hash);

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('adobe_dtm.settings')
      ->set('property_embed_code_id', $form_state->getValue('property_embed_code_id'))
      ->set('property_embed_code_hash', $form_state->getValue('property_embed_code_hash'))
      ->set('environment', $form_state->getValue('environment'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
